@@ -6,7 +6,7 @@ eval_tidyselect <- function(names_quosure, choices) {
   out <- tidyselect::eval_select(names_quosure, data = choices, strict = FALSE)
   out <- names(out)
   assert_chr(
-    out %||% character(0),
+    out %|||% character(0),
     paste(
       "the names arg of tar_make() and friends supports tidyselect syntax",
       "but must resolve to a character vector in the end."
