@@ -61,7 +61,7 @@ targets::tar_test("tar_knit_raw() warns about tar_read_raw()", {
   })
   expect_warning(
     suppressMessages(targets::tar_make(callr_function = NULL)),
-    class = "condition_validate"
+    class = "tar_condition_validate"
   )
 })
 
@@ -88,7 +88,7 @@ targets::tar_test("tar_knit_raw() warns about tar_load_raw()", {
   })
   expect_warning(
     suppressMessages(targets::tar_make(callr_function = NULL)),
-    class = "condition_validate"
+    class = "tar_condition_validate"
   )
 })
 
